@@ -4,7 +4,7 @@
  * mangle names w/ and w/o commas
  *
  * Copyright (c) Chris Putnam 2004-2020
- * Copyright (c) Georgi N. Boshnakov 2020-2021
+ * Copyright (c) Georgi N. Boshnakov 2020-2023
  *
  * Source code released under the GPL version 2
  *
@@ -423,6 +423,31 @@ name_mutlielement_build( str *name, intlist *given, intlist *family, slist *toke
 			      pastslash++;
 		  
 			      break;
+
+			 case 'a':    // 2021-12-19
+			   // \a'o, \a`o, \a=o are used in latex's tabbing environment but
+			   // latex seems to accept them elsewhere AND bibtex seems to
+			   // convert them to \'o, etc. when writing bbl files AND base-R's
+			   // bibtex stuff supports it.
+			   //
+			   // TODO: test more!
+
+			      str_addchar( name, *pastslash );   // emit 'a'
+			      pastslash++;
+			      if(*pastslash=='\'' || *pastslash=='`' || *pastslash=='=') {
+				str_addchar( name, *pastslash ); 
+				pastslash++;
+			      } 
+			      // the rest as for '\'' above
+			      if(*pastslash == '\\' && pastslash[1]) {
+				   str_addchar( name, *pastslash );    // emit the backslash
+				   pastslash++;
+			      } 
+			      str_addchar( name, *pastslash );
+			      pastslash++;
+
+			      break;
+
 			 default: 
 			      str_addchar( name, *pastslash );
 			      str_addchar( name, *(pastslash + 1));
@@ -449,7 +474,6 @@ name_mutlielement_build( str *name, intlist *given, intlist *family, slist *toke
      return 1;
 }
 
-
 static void
 name_fix_latex_escapes( str *name ) {
      // deals with issue #5 (the part ,
@@ -474,6 +498,7 @@ name_fix_latex_escapes( str *name ) {
 			 str_strcatc(name, "{\\");
 		
 			 ch = *pastslash;
+			 // (2022-12-16) TODO: case '"'? !!!
 			 switch(ch) {
 			 case 'O':
 			 case 'o':
@@ -527,6 +552,31 @@ name_fix_latex_escapes( str *name ) {
 			      pastslash++;
 		  
 			      break;
+			        
+			 case 'a':    // 2021-12-19
+			   // \a'o, \a`o, \a=o are used in latex's tabbing environment but
+			   // latex seems to accept them elsewhere AND bibtex seems to
+			   // convert them to \'o, etc. when writing bbl files AND base-R's
+			   // bibtex stuff supports it.
+			   //
+			   // TODO: test more!
+
+			      str_addchar( name, *pastslash );   // emit 'a'
+			      pastslash++;
+			      if(*pastslash=='\'' || *pastslash=='`' || *pastslash=='=') {
+				str_addchar( name, *pastslash ); 
+				pastslash++;
+			      } 
+			      // the rest as for '\'' above
+			      if(*pastslash == '\\' && pastslash[1]) {
+				   str_addchar( name, *pastslash );    // emit the backslash
+				   pastslash++;
+			      } 
+			      str_addchar( name, *pastslash );
+			      pastslash++;
+
+			      break;
+
 			 default: 
 			      str_addchar( name, *pastslash );
 			      str_addchar( name, *(pastslash + 1));
@@ -552,7 +602,6 @@ name_fix_latex_escapes( str *name ) {
      str_delete(mys);
 }
 
-
 static int
 name_construct_multi( str *outname, slist *tokens, int begin, int end )
 {
@@ -623,7 +672,6 @@ name_addmultielement( fields *info, const char *tag, slist *tokens, int begin, i
 	return ok;
 }
 
-
 /* name_addsingleelement()
  *
  * Treat names that are single tokens, e.g. {Random Corporation, Inc.} in bibtex
